﻿' *****************************************************************
' *                                                               *
' *       Copyright (c) Fast Corporation, 2019                    *
' *                                                               *
' *   All Rights Reserved.  Unpublished rights  reserved  under   *
' *   the copyright laws of the Japan.                            *
' *                                                               *
' *   The software contained on this media  is  proprietary  to   *
' *   and  embodies  the  confidential  technology  of  Fast      *
' *   Corporation.  Possession, use,  duplication  or             *
' *   dissemination of the software and media is authorized only  *
' *   pursuant to a valid written license from Fast Corporation.  *
' *                                                               *
' *****************************************************************

' -----------------------------------------------------------------
' FVIL Sample Program
' メインダイアログ
'
' 作成者 : N.Kubo
'
' 履歴 : 2019/01/28 初版
'
' FVC07 1ch only Sample Program
' -----------------------------------------------------------------

Public Class Form1

    Private m_image As FVIL.Data.CFviImage = New FVIL.Data.CFviImage()              '画像メモリ格納領域
    Private m_video As FVIL.Video.CFviVideoFVC07 = New FVIL.Video.CFviVideoFVC07    'FVC07クラス
    Private m_timer As FVIL.CFviTimeCounter = New FVIL.CFviTimeCounter()            '処理時間計測クラス

    Dim intErr As Integer                                                           'エラー番号格納変数
    Public m_strIniFilePath As String                                              'iniファイル名（フルパス）

    Private m_flgVideoOpened As Boolean                                             'ビデオデバイスのオープン状態
    Private m_flgFreerun As Boolean                                                 'フリーランの状態


    Private Sub Form1_Load(sender As Object, e As EventArgs) Handles MyBase.Load

        'FVILの初期化
        'アプリケーションを起動した後、 この関数を呼び出してライブラリを初期化してください。 
        'この時、ライセンスの認証が行われます。試用期間中であっても、この処理は必ず行う必要が有ります。 
        '初期化を行わなかった場合は、プロテクトされたクラスの実行ができません。
        FVIL._SetUp.InitVisionLibrary()

        '状態変数の初期化
        m_flgVideoOpened = False
        m_flgFreerun = False

        '計測時間テキストボックス初期化
        TextBoxTime.Text = "0"

        'エンコーダパラメータコンボボックス初期化
        ComboBoxSignal.Items.Clear()
        ComboBoxSignal.Items.Add("AB相")
        ComboBoxSignal.Items.Add("A相")

        ComboBoxMlt.Items.Clear()
        ComboBoxMlt.Items.Add("1倍")
        ComboBoxMlt.Items.Add("2倍")
        ComboBoxMlt.Items.Add("4倍")

        ComboBoxStart.Items.Clear()
        ComboBoxStart.Items.Add("CPU")
        ComboBoxStart.Items.Add("外部トリガ")
        ComboBoxStart.Items.Add("Z相")

        ComboBoxPulse.Items.Clear()
        ComboBoxPulse.Items.Add("CW")
        ComboBoxPulse.Items.Add("CCW")

        ComboBoxInit.Items.Clear()
        ComboBoxInit.Items.Add("初期化する")
        ComboBoxInit.Items.Add("初期化しない")

        'トリガモードコンボボックス初期化
        ComboBoxTrigger.Items.Clear()
        ComboBoxTrigger.Items.Add("ノーマル")
        ComboBoxTrigger.Items.Add("内部トリガ")
        ComboBoxTrigger.Items.Add("外部トリガ")
        ComboBoxTrigger.Items.Add("外部トリガ2")
        ComboBoxTrigger.SelectedIndex = 0

        'サイクルタイムモードコンボンボボックス初期化
        ComboBoxCycleTimeMode.Items.Clear()
        ComboBoxCycleTimeMode.Items.Add("トリガ幅を含まない時間")
        ComboBoxCycleTimeMode.Items.Add("トリガ幅を含む時間")


    End Sub

    ''' <summary>
    ''' フォーム表示開始 イベントハンドラ
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 使用許諾を確認します。
    ''' </remarks>
    Private Sub Form1_Shown(sender As Object, e As EventArgs) Handles MyBase.Shown
        '使用許諾の確認
        Dim licence_dialog As New dialogLicence
        If (licence_dialog.ShowDialog(Me) <> System.Windows.Forms.DialogResult.OK) Then
            Me.Close() '使用許諾が得られない場合はサンプルプログラムの動作を終了
            Exit Sub
        End If

        'iniファイル選択
        fnSetIniFile()

        CFviImageView1.Image = Me.m_image
    End Sub


    ''' <summary>
    ''' 終了処理
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' アプリケーション終了処理。
    ''' </remarks>
    Private Sub Form1_FormClosing(sender As Object, e As FormClosingEventArgs) Handles MyBase.FormClosing

        'ビデオデバイスがオープンされていた場合はクローズする
        If (m_flgVideoOpened = True) Then
            m_video.Close()
            m_flgVideoOpened = False
        End If

    End Sub

    ''' <summary>
    ''' iniファイル選択関数
    ''' </summary>
    ''' <remarks>
    ''' iniファイルの選択をします。
    ''' </remarks>
    Private Sub fnSetIniFile()

        Dim formbroseini As New Form_BROWSEINI  'iniファイル設定画面

        'iniファイルの選択
        m_strIniFilePath = ""

        If (Form_BROWSEINI.ShowDialog(Me) = System.Windows.Forms.DialogResult.OK) Then
            m_strIniFilePath = Form_BROWSEINI.strIniFilePath
        End If

        If (m_strIniFilePath.Length > 0) Then

            Dim configuration As Integer = 0
            Try
                'ビデオデバイスがオープンされていた場合はクローズする
                If (m_video.IsOpen = True) Then
                    m_video.Close()
                    m_flgVideoOpened = False
                End If

                'カメラのコンフィグレーションをiniファイルから取得する
                Dim flgini As Boolean = False
                Dim compare, Correctleng, leng As Integer
                Dim CorrectStr, readstr, tempstr As String
                Dim read As System.IO.StreamReader
                CorrectStr = "Configuration="
                read = New System.IO.StreamReader(m_strIniFilePath)
                Correctleng = CorrectStr.Length

                Do Until flgini <> False
                    readstr = read.ReadLine()
                    leng = readstr.Length
                    If (leng > Correctleng) Then
                        leng = Correctleng
                    End If
                    tempstr = readstr.Substring(0, leng)
                    compare = tempstr.CompareTo(CorrectStr)
                    If (compare = 0) Then
                        configuration = readstr.Substring(Correctleng, 1)
                        flgini = True
                    End If
                Loop
                read.Close()

                'デバイスオープン
                m_video.Open(-1, configuration, -1)
                m_flgVideoOpened = True

                'VideoConfFileの変更後、OpenDeviceを行うと、トリガーモードの変更が伴います
                '弊社キャプチャボードはトリガーモードの設定後にセットアップタイムが必要になります｡
                '本プログラムのセットアップタイムは必要最大値である350msを設定しています。
                'キャプチャボードによってこの時間は異なります。
                Threading.Thread.Sleep(350)

                'iniファイルをコンポーネントに設定
                If (m_strIniFilePath.Length > 0) Then
                    m_video.LoadIniFile(m_strIniFilePath)
                End If

                '取込画像を正規化
                m_video.ChangeImageSize(m_image)

                '初期値を表示
                'ラインセンサモード
                CheckLineSensorMode.Checked = m_video.LineSensorMode.LsEnable
                ChecEncoderMode.Checked = m_video.LineSensorMode.EncEnable

                'エンコーダモード
                ComboBoxSignal.SelectedIndex = m_video.EncoderParam.Signal
                ComboBoxSignal.SelectedIndex = m_video.EncoderParam.Signal
                ComboBoxMlt.SelectedIndex = m_video.EncoderParam.Mlt
                ComboBoxStart.SelectedIndex = m_video.EncoderParam.Start
                ComboBoxPulse.SelectedIndex = m_video.EncoderParam.Pulse
                NumericUpDownComp1.Value = m_video.EncoderParam.Comp1
                NumericUpDownComp2.Value = m_video.EncoderParam.Comp2
                ComboBoxInit.SelectedIndex = m_video.EncoderParam.Init

                'トリガモード取得
                ComboBoxTrigger.SelectedIndex = m_video.Trigger
                ComboBoxCycleTimeMode.SelectedIndex = m_video.TriggerCycleTime.Mode
                NumericUpDownExposure.Value = m_video.ExposureTime
                NumericUpDownCycleTime.Value = m_video.TriggerCycleTime.Time

                'エンコーダモード時、エンコーダパラメータ変更可
                GroupEncorderParam.Enabled = ChecEncoderMode.Checked

            Catch ex As Exception

                'エラー処理
                intErr = m_video.ErrorCode
                MessageBox.Show("ErrorCode= " + intErr.ToString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
            End Try

        Else
            'iniファイルが未選択の場合はサンプルプログラムの動作を終了
            Me.Close()
            Exit Sub
        End If

    End Sub

    ''' <summary>
    ''' Grab Oneボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' カメラ取り込み。
    ''' </remarks>
    Private Sub ButtonGrabOne_Click(sender As Object, e As EventArgs) Handles ButtonGrabOne.Click

        Dim msec As Double

        Try
            m_timer.Start()                             '時間測定開始
            'カメラ取り込み
            m_video.GrabImageSync(m_image)
            msec = m_timer.Stop()                       '時間測定終了
            TextBoxTime.Text = msec.ToString("0.000")   '測定時間表示
            '再描画
            CFviImageView1.Refresh()
        Catch ex As Exception
            'エラー処理
            intErr = m_video.ErrorCode
            MessageBox.Show("ErrorCode= " + intErr.ToString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

    End Sub


    ''' <summary>
    ''' Grab Continueボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' フリーラン開始・停止。
    ''' </remarks>
    Private Sub ButtonGrabContinue_Click(sender As Object, e As EventArgs) Handles ButtonGrabContinue.Click

        'ボタン表示変更
        If (m_flgFreerun = True) Then
            ButtonGrabContinue.Text = "Grab Continue"
            ButtonGrabOne.Enabled = True
            m_flgFreerun = False
            Timer1.Enabled = False
        Else
            ButtonGrabContinue.Text = "Stop"
            ButtonGrabOne.Enabled = False
            m_flgFreerun = True
            Timer1.Interval = 100
            Timer1.Start()
        End If
        Application.DoEvents()

    End Sub


    ''' <summary>
    ''' Trigger Modeコンボボックス
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' ノーマルモード・内部トリガモード・外部トリガモードの選択。
    ''' </remarks>
    Private Sub ComboBoxTrigger_SelectedIndexChanged(sender As Object, e As EventArgs) Handles ComboBoxTrigger.SelectedIndexChanged
        Try
            If (m_flgVideoOpened = True) Then
                m_video.Trigger = ComboBoxTrigger.SelectedIndex
                '弊社キャプチャボードはトリガーモードの設定後にセットアップタイムが必要になります｡
                '本プログラムのセットアップタイムは必要最大値である350msを設定しています。
                'キャプチャボードによってこの時間は異なります。
                Threading.Thread.Sleep(350)
            End If
        Catch ex As Exception
            'エラー処理
            intErr = m_video.ErrorCode
            MessageBox.Show("ErrorCode= " + intErr.ToString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub



    ''' <summary>
    ''' CycleTime Mode 変更
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' サイクルタイムのモード変更
    ''' </remarks>
    Private Sub ComboBoxCycleTimeMode_SelectedIndexChanged(sender As Object, e As EventArgs) Handles ComboBoxCycleTimeMode.SelectedIndexChanged

        Try
            If (m_flgVideoOpened = True) Then

                Dim trgcycle As FVIL.Video.CFviTriggerCycleTime = m_video.TriggerCycleTime
                trgcycle.Mode = ComboBoxCycleTimeMode.SelectedIndex
                m_video.TriggerCycleTime = trgcycle

            End If
        Catch ex As Exception
            'エラー処理
            intErr = m_video.ErrorCode
            MessageBox.Show("ErrorCode= " + intErr.ToString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

    End Sub

    ''' <summary>
    ''' CycleTime変更
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' サイクルタイム変更
    ''' </remarks>
    Private Sub NumericUpDownCycleTime_ValueChanged(sender As Object, e As EventArgs) Handles NumericUpDownCycleTime.ValueChanged

        Try
            If (m_flgVideoOpened = True) Then
                Dim trgcycle As FVIL.Video.CFviTriggerCycleTime = m_video.TriggerCycleTime
                trgcycle.Time = NumericUpDownCycleTime.Value
                m_video.TriggerCycleTime = trgcycle

            End If
        Catch ex As Exception
            'エラー処理
            intErr = m_video.ErrorCode
            MessageBox.Show("ErrorCode= " + intErr.ToString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

    End Sub

    ''' <summary>
    ''' Exposure NumericUpDown
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' カメラ露光時間の設定。
    ''' </remarks>
    Private Sub NumericUpDownExposure_ValueChanged(sender As Object, e As EventArgs) Handles NumericUpDownExposure.ValueChanged

        Try
            If (m_flgVideoOpened = True) Then
                m_video.ExposureTime = NumericUpDownExposure.Value
            End If
        Catch ex As Exception
            'エラー処理
            intErr = m_video.ErrorCode
            MessageBox.Show("ErrorCode= " + intErr.ToString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try


    End Sub


    ''' <summary>
    ''' ReLoad Ini Fileボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' ビデオ設定用iniファイルの再設定。
    ''' </remarks>
    Private Sub ButtonReLoadIni_Click(sender As Object, e As EventArgs) Handles ButtonReLoadIni.Click

        'フリーラン中ならば、停止する。
        If (m_flgFreerun = True) Then
            ButtonGrabContinue.Text = "Grab Continue"
            ButtonGrabOne.Enabled = True
            m_flgFreerun = False
            Timer1.Enabled = False
            Application.DoEvents()
        End If

        'iniファイル選択
        fnSetIniFile()

    End Sub


    ''' <summary>
    ''' Save Imageボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 表示画像保存
    ''' </remarks>
    Private Sub ButtonSaveImage_Click(sender As Object, e As EventArgs) Handles ButtonSaveImage.Click
        Dim ofdlg As SaveFileDialog = New SaveFileDialog()
        ofdlg.Filter = "画像ファイル(*.bmp;*.dib;*.png;*.jpg;*.jpeg;*.tif;*.tiff;*.raw;*.pat)|*.bmp;*.dib;*.png;*.jpg;*.jpeg;*.tif;*.tiff;*.raw;*.pat"
        ofdlg.Filter += "|Bitmap ファイル (*.bmp;*.dib)|*.bmp;*.dib"
        ofdlg.Filter += "|Png ファイル (*.png)|*.png"
        ofdlg.Filter += "|Jpeg ファイル (*.jpg;*.jpeg)|*.jpg;*.jpeg"
        ofdlg.Filter += "|Tiff ファイル (*.tif;*.tiff)|*.tif;*.tiff"
        ofdlg.Filter += "|Raw ファイル (*.raw)|*.raw"
        ofdlg.Filter += "|すべてのファイル (*.*)|*.*"
        ofdlg.OverwritePrompt = True

        If (ofdlg.ShowDialog(Me) = System.Windows.Forms.DialogResult.OK) Then
            Try
                'この関数は、簡易的に画像ファイルの保存を行う為のものです。 
                'この関数で指定できないパラメータを指定する必要があれば、 各画像ファイルアクセスクラスを直接使用してください。 
                FVIL.File.Function.SaveImageFile(ofdlg.FileName, CFviImageView1.Image)

                '保存するファイル形式が固定の場合は、以下のように記述します。
                '例1) bmpファイルの場合
                'Dim file As FVIL.File.CFviImageFileBmp = New FVIL.File.CFviImageFileBmp()
                'file.Save(ofdlg.FileName, m_image)

                '例2) jpgファイルの場合
                'Dim file As FVIL.File.CFviImageFileJpg = New FVIL.File.CFviImageFileJpg()
                'file.Save(ofdlg.FileName, m_image)

            Catch ex As FVIL.CFviException
                Dim msg As System.String = System.String.Format("ライブラリが例外を発行しました。code={0} func={1}", ex.ErrorCode, ex.Function)
                Select Case (ex.ErrorCode)
                    Case FVIL.ErrorCode.NOT_SUPPORTED,
                     FVIL.ErrorCode.INVALID_OBJECT
                        msg += vbCrLf + "サポートされていない画像オブジェクトです。"
                        msg += vbCrLf + "Raw 形式で保存してください。"
                End Select
                MessageBox.Show(msg, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
            Catch ex As Exception
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)

            End Try
        End If
    End Sub


    ''' <summary>
    ''' Fitボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 画像全体がビューのクライアント領域に表示できるように表示倍率を縮小(または拡大)します
    ''' </remarks>
    Private Sub ButtonMag1_Click(sender As Object, e As EventArgs) Handles ButtonMag1.Click
        '画像の表示倍率の取得または設定を行います。1.0と指定すると等倍で表示します。
        '倍率値は、0.5とした場合は、幅・高さ共に1/2となり、面積が1/4になります。
        '3.0とした場合は、幅・高さ共に3倍となり、面積が9倍になります。
        CFviImageView1.Display.Magnification = 1.0      '表示倍率の設定
        CFviImageView1.Refresh()                        '再描画

    End Sub


    ''' <summary>
    ''' Fitボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 画像全体がビューのクライアント領域に表示できるように表示倍率を縮小(または拡大)します
    ''' </remarks>
    Private Sub ButtonFit_Click(sender As Object, e As EventArgs) Handles ButtonFit.Click
        '画像全体がビューのクライアント領域に表示できるように表示倍率を縮小(または拡大)します
        CFviImageView1.FitImageSize()                   '表示倍率を調整
        CFviImageView1.Refresh()                        '再描画

    End Sub

    ''' <summary>
    ''' ＋ボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 現在の倍率に0.5加えた倍率で表示します。
    ''' </remarks>
    Private Sub ButtonPlus_Click(sender As Object, e As EventArgs) Handles ButtonPlus.Click
        Dim Value As Double
        Value = CFviImageView1.Display.Magnification    '現倍率の取得
        Value = Value + 0.5
        CFviImageView1.Display.Magnification = Value    '表示倍率の設定
        CFviImageView1.Refresh()                        '再描画

    End Sub


    ''' <summary>
    ''' －ボタン
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 現在の倍率から0.5引いた倍率で表示します。ただし、倍率が０以下になる場合は倍率0.1で表示します。
    ''' </remarks>
    Private Sub ButtonMinus_Click(sender As Object, e As EventArgs) Handles ButtonMinus.Click
        Dim Value As Double
        Value = CFviImageView1.Display.Magnification    '現倍率の取得
        Value = Value - 0.5
        If (Value <= 0) Then
            Value = 0.1       '０以下を設定するとエラーになるので0.1を設定する
        End If
        CFviImageView1.Display.Magnification = Value    '表示倍率の設定
        CFviImageView1.Refresh()                        '再描画

    End Sub
    ''' <summary>
    ''' Ascopeチェックボックス
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' ASCOPEの表示を切替えます。
    ''' </remarks>
    Private Sub CheckBoxAscope_CheckedChanged(sender As Object, e As EventArgs) Handles CheckBoxAscope.CheckedChanged
        'ASCOPEオーバレイの設定
        If (CheckBoxAscope.CheckState) Then
            'ASCOPEの表示を有効にする。
            CFviImageView1.Display.OverlayAscope.Enable = True
            CFviImageView1.Display.OverlayAscope.Active = True
        Else
            'ASCOPEの表示を無効にする。
            CFviImageView1.Display.OverlayAscope.Enable = False
            CFviImageView1.Display.OverlayAscope.Active = False
        End If
        CFviImageView1.Refresh()
    End Sub

    ''' <summary>
    ''' エンコーダモードチェックボックス
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' エンコーダモードに変更します。
    ''' </remarks>
    Private Sub ChecEncoderMode_CheckedChanged(sender As Object, e As EventArgs) Handles ChecEncoderMode.CheckedChanged

        Try
            If (m_flgVideoOpened = True) Then
                Dim linemode As FVIL.Video.CFviLineSensorMode = m_video.LineSensorMode
                linemode.EncEnable = System.Convert.ToUInt32(ChecEncoderMode.Checked)
                m_video.LineSensorMode = linemode

            End If
        Catch ex As Exception
            'エラー処理
            intErr = m_video.ErrorCode
            MessageBox.Show("ErrorCode= " + intErr.ToString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

        'エンコーダーモードのときのみパラメータ変更化
        GroupEncorderParam.Enabled = ChecEncoderMode.Checked

    End Sub

    ''' <summary>
    ''' シリアル通信
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' カメラ設定を変更します。
    ''' </remarks>
    Private Sub ButtonSendSIO_Click(sender As Object, e As EventArgs) Handles ButtonSendSIO.Click
        Dim senddata As New List(Of Byte)(System.Text.Encoding.ASCII.GetBytes(TextBoxSendData.Text))
        Dim revdata As New List(Of Byte)
        Dim i As Integer

        Try
            TextBoxRecieveData.Text = ""
            m_video.Sio.Open()
            revdata = m_video.Sio.SendData(senddata, 0)

            'Byteに変換
            Dim byterevdata As Byte() = revdata.ToArray()

            '受信データを表示
            For i = 0 To revdata.Count - 1
                TextBoxRecieveData.Text = System.Text.Encoding.ASCII.GetString(byterevdata)
            Next

        Catch ex As FVIL.CFviException
            Dim msg As System.String = System.String.Format("ライブラリが例外を発行しました。code={0} func={1}", ex.ErrorCode, ex.Function)
            MessageBox.Show(msg, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Catch ex As Exception
            MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        Finally
            m_video.Sio.Close()
        End Try

    End Sub


    ''' <summary>
    ''' ラインセンサモード
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' カメラ設定（エリア　Or ラインセンサか指定する）
    ''' </remarks>
    Private Sub CheckLineSensorMode_CheckedChanged(sender As Object, e As EventArgs) Handles CheckLineSensorMode.CheckedChanged
        Try
            If (m_flgVideoOpened = True) Then
                Dim linemode As FVIL.Video.CFviLineSensorMode = m_video.LineSensorMode
                linemode.LsEnable = System.Convert.ToUInt32(CheckLineSensorMode.Checked)
                m_video.LineSensorMode = linemode

            End If
        Catch ex As Exception
            'エラー処理
            intErr = m_video.ErrorCode
            MessageBox.Show("ErrorCode= " + intErr.ToString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

    End Sub


    ''' <summary>
    '''  エンコーダパラメータ
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' AB相設定( 0:AB相、1:A相 )
    ''' </remarks>
    Private Sub ComboBoxSignal_SelectedIndexChanged(sender As Object, e As EventArgs) Handles ComboBoxSignal.SelectedIndexChanged
        Try
            If (m_flgVideoOpened = True) Then
                Dim encmode As FVIL.Video.CFviEncoderParam2 = m_video.EncoderParam

                encmode.Signal = ComboBoxSignal.SelectedIndex
                m_video.EncoderParam = encmode

            End If
        Catch ex As Exception
            'エラー処理
            intErr = m_video.ErrorCode
            MessageBox.Show("ErrorCode= " + intErr.ToString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

    End Sub

    ''' <summary>
    '''  エンコーダパラメータ
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' サンプリング速度 ( 0:1倍、1:2倍、2:4倍 )
    ''' </remarks>
    Private Sub ComboBoxMlt_SelectedIndexChanged(sender As Object, e As EventArgs) Handles ComboBoxMlt.SelectedIndexChanged
        Try
            If (m_flgVideoOpened = True) Then
                Dim encmode As FVIL.Video.CFviEncoderParam2 = m_video.EncoderParam
                encmode.Mlt = ComboBoxMlt.SelectedIndex
                m_video.EncoderParam = encmode

            End If
        Catch ex As Exception
            'エラー処理
            intErr = m_video.ErrorCode
            MessageBox.Show("ErrorCode= " + intErr.ToString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

    End Sub

    ''' <summary>
    '''  エンコーダパラメータ
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' エンコーダ起動モード( 0:CPU、1:外部トリガ、2:Z相 )
    ''' </remarks>
    Private Sub ComboBoxStart_SelectedIndexChanged(sender As Object, e As EventArgs) Handles ComboBoxStart.SelectedIndexChanged
        Try
            If (m_flgVideoOpened = True) Then
                Dim encmode As FVIL.Video.CFviEncoderParam2 = m_video.EncoderParam
                encmode.Start = ComboBoxStart.SelectedIndex
                m_video.EncoderParam = encmode

            End If
        Catch ex As Exception
            'エラー処理
            intErr = m_video.ErrorCode
            MessageBox.Show("ErrorCode= " + intErr.ToString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

    End Sub


    ''' <summary>
    '''  エンコーダパラメータ
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' パルスの方向 ( 0:CW、1:CCW )
    ''' </remarks>
    Private Sub ComboBoxPulse_SelectedIndexChanged(sender As Object, e As EventArgs) Handles ComboBoxPulse.SelectedIndexChanged
        Try
            If (m_flgVideoOpened = True) Then
                Dim encmode As FVIL.Video.CFviEncoderParam2 = m_video.EncoderParam
                encmode.Pulse = ComboBoxPulse.SelectedIndex
                m_video.EncoderParam = encmode

            End If
        Catch ex As Exception
            'エラー処理
            intErr = m_video.ErrorCode
            MessageBox.Show("ErrorCode= " + intErr.ToString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

    End Sub

    ''' <summary>
    ''' エンコーダパラメータ
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    '''  <remarks>
    ''' エンコーダカウン
    ''' </remarks>
    Private Sub ComboBoxInit_SelectedIndexChanged(sender As Object, e As EventArgs) Handles ComboBoxInit.SelectedIndexChanged
        Try
            If (m_flgVideoOpened = True) Then
                Dim encmode As FVIL.Video.CFviEncoderParam2 = m_video.EncoderParam
                encmode.Init = ComboBoxInit.SelectedIndex
                m_video.EncoderParam = encmode

            End If
        Catch ex As Exception
            'エラー処理
            intErr = m_video.ErrorCode
            MessageBox.Show("ErrorCode= " + intErr.ToString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
    End Sub


    ''' <summary>
    ''' エンコーダパラメータ
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 比較レジスタ1
    ''' </remarks>
    Private Sub NumericUpDownComp1_ValueChanged(sender As Object, e As EventArgs) Handles NumericUpDownComp1.ValueChanged
        Try
            If (m_flgVideoOpened = True) Then
                Dim encmode As FVIL.Video.CFviEncoderParam2 = m_video.EncoderParam
                encmode.Comp1 = NumericUpDownComp1.Value
                m_video.EncoderParam = encmode

            End If
        Catch ex As Exception
            'エラー処理
            intErr = m_video.ErrorCode
            MessageBox.Show("ErrorCode= " + intErr.ToString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

    End Sub

    ''' <summary>
    ''' エンコーダパラメータ
    ''' </summary>
    ''' <param name="sender"></param>
    ''' <param name="e"></param>
    ''' <remarks>
    ''' 比較レジスタ2
    ''' </remarks>
    Private Sub NumericUpDownComp2_ValueChanged(sender As Object, e As EventArgs) Handles NumericUpDownComp2.ValueChanged
        Try
            If (m_flgVideoOpened = True) Then
                Dim encmode As FVIL.Video.CFviEncoderParam2 = m_video.EncoderParam
                encmode.Comp2 = NumericUpDownComp2.Value
                m_video.EncoderParam = encmode

            End If
        Catch ex As Exception
            'エラー処理
            intErr = m_video.ErrorCode
            MessageBox.Show("ErrorCode= " + intErr.ToString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try

    End Sub

    ''' <summary>
    ''' フリーラン
    ''' </summary>
    ''' <remarks>
    ''' 連続カメラ取り込み。
    ''' </remarks>
    Private Sub Timer1_Tick(sender As Object, e As EventArgs) Handles Timer1.Tick

        Dim msec As Double

        Timer1.Stop()

        Try
            If (m_flgVideoOpened = True) Then
                m_timer.Start()                            '時間測定開始
                'カメラ取り込み
                m_video.GrabImageSync(m_image)
                msec = m_timer.Stop()                      '時間測定終了
                TextBoxTime.Text = msec.ToString("0.000")  '測定時間表示
            End If
            Timer1.Enabled = True

        Catch ex As Exception

            ButtonGrabContinue.Text = "Grab Continue"
            ButtonGrabOne.Enabled = True
            m_flgFreerun = False
            Timer1.Enabled = False

            'エラー処理
            intErr = m_video.ErrorCode
            MessageBox.Show("ErrorCode= " + intErr.ToString, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error)
        End Try
        '再描画
        CFviImageView1.Refresh()

    End Sub
End Class
